package de.hhhammer.dchat.bot.discord;

import de.hhhammer.dchat.bot.openai.ResponseException;
import org.javacord.api.entity.message.MessageType;
import org.javacord.api.event.message.MessageCreateEvent;
import org.javacord.api.listener.message.MessageCreateListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;

public final class MessageCreateHandler implements MessageCreateListener {
    private static final Logger logger = LoggerFactory.getLogger(MessageCreateHandler.class);

    private final MessageHandler messageHandler;

    public MessageCreateHandler(final MessageHandler messageHandler) {
        this.messageHandler = messageHandler;
    }

    @Override
    public void onMessageCreate(final MessageCreateEvent event) {
        Thread.ofVirtual().start(() -> {
            if (!event.canYouReadContent() || event.getMessageAuthor().isBotUser() || !isNormalOrReplyMessageType(event)) {
                return;
            }
            if (!this.messageHandler.canHandle(event)) {
                return;
            }
            if (!this.messageHandler.isAllowed(event)) {
                return;
            }
            if (this.messageHandler.exceedsRate(event)) {
                event.getChannel().sendMessage("Rate limit hit - cooling down...");
                return;
            }
            try {
                this.messageHandler.handle(event);
            } catch (final ResponseException | IOException | InterruptedException e) {
                logger.error("Reading a message from the listener", e);
                event.getMessage().reply("Sorry but something went wrong :(");
            }
        });
    }

    private boolean isNormalOrReplyMessageType(final MessageCreateEvent event) {
        final MessageType type = event.getMessage().getType();
        return type == MessageType.NORMAL || type == MessageType.REPLY;
    }
}
