package de.hhhammer.dchat.db.models.server;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import de.hhhammer.dchat.db.ResultSetTransformer;
import org.jetbrains.annotations.Nullable;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.time.Instant;

public record ServerConfig(long id, String serverId, String systemMessage, int rateLimit, Instant time) {

    public static class ServerConfigResultSetTransformer implements ResultSetTransformer<ServerConfig> {

        @Override
        public ServerConfig transform(ResultSet resultSet) throws SQLException {
            var id = resultSet.getLong("id");
            var serverId = resultSet.getString("server_id");
            var systemMessage = resultSet.getString("system_message");
            var rateLimit = resultSet.getInt("rate_limit");
            var time = resultSet.getTimestamp("time").toInstant();
            return new ServerConfig(id, serverId, systemMessage, rateLimit, time);
        }
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public record NewServerConfig(String serverId, String systemMessage, @Nullable int rateLimit) {
    }
}
