package de.hhhammer.dchat.db.models.server;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import de.hhhammer.dchat.db.ResultSetTransformer;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.time.Instant;

public record ServerMessage(long id, String serverId, long userId, int tokens, Instant time) {

    public static class ServerMessageResultSetTransformer implements ResultSetTransformer<ServerMessage> {

        @Override
        public ServerMessage transform(ResultSet resultSet) throws SQLException {
            var id = resultSet.getLong("id");
            var serverId = resultSet.getString("server_id");
            var userId = resultSet.getLong("user_id");
            var tokens = resultSet.getInt("tokens");
            var time = resultSet.getTimestamp("time").toInstant();
            return new ServerMessage(id, serverId, userId, tokens, time);
        }
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public record NewServerMessage(String serverId, long userId, int tokens) {
    }
}
