package de.hhhammer.dchat.db.models.user;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import de.hhhammer.dchat.db.ResultSetTransformer;
import org.jetbrains.annotations.Nullable;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.time.Instant;

public record UserConfig(long id, String userId, String systemMessage, int contextLength, int rateLimit, Instant time) {

    public static class UserConfigResultSetTransformer implements ResultSetTransformer<UserConfig> {

        @Override
        public UserConfig transform(ResultSet resultSet) throws SQLException {
            var id = resultSet.getLong("id");
            var userId = resultSet.getString("user_id");
            var systemMessage = resultSet.getString("system_message");
            var contextLength = resultSet.getInt("context_length");
            var rateLimit = resultSet.getInt("rate_limit");
            var time = resultSet.getTimestamp("time").toInstant();
            return new UserConfig(id, userId, systemMessage, contextLength, rateLimit, time);
        }
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public record NewUserConfig(String userId, String systemMessage, @Nullable int contextLength,
                                @Nullable int rateLimit) {
    }
}
