package de.hhhammer.dchat.db.models.user;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import de.hhhammer.dchat.db.ResultSetTransformer;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.time.Instant;

public record UserMessage(long id, String userId, String question, String answer, int tokens, Instant time) {

    public static class UserMessageResultSetTransformer implements ResultSetTransformer<UserMessage> {

        @Override
        public UserMessage transform(ResultSet resultSet) throws SQLException {
            var id = resultSet.getLong("id");
            var userId = resultSet.getString("user_id");
            var question = resultSet.getString("question");
            var answer = resultSet.getString("answer");
            var tokens = resultSet.getInt("tokens");
            var time = resultSet.getTimestamp("time").toInstant();
            return new UserMessage(id, userId, question, answer, tokens, time);
        }
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public record NewUserMessage(String userId, String question, String answer, int tokens) {
    }
}
