package de.hhhammer.dchat.migration;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.io.InputStream;

public final class DBMigrator implements Runnable {
    private static final Logger logger = LoggerFactory.getLogger(DBMigrator.class);
    private final MigrationExecutor migrationExecutor;
    private final String resourcePath;

    public DBMigrator(final MigrationExecutor migrationExecutor, final String resourcePath) {
        this.migrationExecutor = migrationExecutor;
        this.resourcePath = resourcePath;
    }

    @Override
    public void run() {
        logger.info("Starting db migration");
        final ClassLoader classLoader = getClass().getClassLoader();
        try (final InputStream inputStream = classLoader.getResourceAsStream(this.resourcePath)) {
            if (inputStream == null) {
                logger.error("Migration file not found: " + resourcePath);
                throw new RuntimeException("Migration file not found");
            }
            migrationExecutor.migrate(inputStream);
        } catch (IOException | DBMigrationException e) {
            throw new RuntimeException(e);
        }
        logger.info("Finished migration");
    }
}
