package de.hhhammer.dchat.migration;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;

public final class MigrationExecutor {
    private static final Logger logger = LoggerFactory.getLogger(MigrationExecutor.class);
    private final String jdbcConnectionString;
    private final String username;
    private final String password;

    public MigrationExecutor(final String jdbcConnectionString, final String username, final String password) {
        this.jdbcConnectionString = jdbcConnectionString;
        this.username = username;
        this.password = password;
    }

    public void migrate(final InputStream input) throws DBMigrationException {
        try (final Connection con = DriverManager
                .getConnection(this.jdbcConnectionString, this.username, this.password);
             final Statement stmp = con.createStatement();
        ) {
            final String content = new String(input.readAllBytes(), StandardCharsets.UTF_8);
            stmp.execute(content);
        } catch (SQLException | IOException e) {
            throw new DBMigrationException(e);
        }
    }

}
