BEGIN;

CREATE TABLE IF NOT EXISTS allowed_servers (
    id SERIAL PRIMARY KEY,
    server_id BIGINT NOT NULL,
    comment TEXT,
    time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
);

CREATE TABLE IF NOT EXISTS server_configs (
    id SERIAL PRIMARY KEY,
    server_id BIGINT NOT NULL,
    system_message TEXT NOT NULL,
    rate_limit INT NOT NULL DEFAULT 10,
    context_length INT NOT NULL DEFAULT 0
);

CREATE TABLE IF NOT EXISTS server_messages (
    id SERIAL PRIMARY KEY,
    server_id BIGINT NOT NULL,
    user_id BIGINT NOT NULL,
    question TEXT NOT NULL,
    answer TEXT NOT NULL,
    tokens int NOT NULL,
    time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
);

COMMIT;

BEGIN;
-- Remove unneeded question and answer from server_messages.
-- We only support using reply function on servers.
ALTER TABLE server_messages
DROP COLUMN IF EXISTS question;

ALTER TABLE server_messages
DROP COLUMN IF EXISTS answer;

-- Remove unused context_length from server_config
-- We only support using reply function on servers.
ALTER TABLE server_configs
DROP COLUMN IF EXISTS context_length;

COMMIT;

-- Add user support
BEGIN;

CREATE TABLE IF NOT EXISTS allowed_users (
    id SERIAL PRIMARY KEY,
    user_id BIGINT NOT NULL,
    comment TEXT,
    time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
);

CREATE TABLE IF NOT EXISTS user_configs (
    id SERIAL PRIMARY KEY,
    user_id BIGINT NOT NULL,
    system_message TEXT NOT NULL,
    rate_limit INT NOT NULL DEFAULT 10
);

CREATE TABLE IF NOT EXISTS user_messages (
    id SERIAL PRIMARY KEY,
    user_id BIGINT NOT NULL,
    tokens int NOT NULL,
    time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
);

COMMIT;

-- Add question and response to the saved user message to be able to generate a conversation context
BEGIN;

ALTER TABLE user_messages
ADD COLUMN IF NOT EXISTS question TEXT NOT NULL;

ALTER TABLE user_messages
ADD COLUMN IF NOT EXISTS answer TEXT NOT NULL;

COMMIT;

-- Add a limit to the context length
BEGIN;

ALTER TABLE user_configs
ADD COLUMN IF NOT EXISTS context_length INT NOT NULL DEFAULT 5;

COMMIT;

-- Add time to config to know when it was added
BEGIN;

ALTER TABLE server_configs
ADD COLUMN IF NOT EXISTS time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP;

ALTER TABLE user_configs
ADD COLUMN IF NOT EXISTS time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP;

COMMIT;

-- Remove obsolete allowed tables that are being replaced the configs tables
BEGIN;

DROP TABLE IF EXISTS allowed_servers;
DROP TABLE IF EXISTS allowed_users;

COMMIT;

BEGIN;

ALTER TABLE server_configs
ALTER COLUMN server_id TYPE text USING server_id::text;

ALTER TABLE server_messages
ALTER COLUMN server_id TYPE text USING server_id::text;

ALTER TABLE user_configs
ALTER COLUMN user_id TYPE text USING user_id::text;

ALTER TABLE user_messages
ALTER COLUMN user_id TYPE text USING user_id::text;

COMMIT;
