package de.hhhammer.dchat.web;

import com.zaxxer.hikari.HikariConfig;
import com.zaxxer.hikari.HikariDataSource;
import de.hhhammer.dchat.db.PostgresServerDBService;
import de.hhhammer.dchat.db.PostgresUserDBService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Hello world!
 */
public final class App {
    private static final Logger logger = LoggerFactory.getLogger(App.class);

    public static void main(final String[] args) {
        final String postgresUser = System.getenv("POSTGRES_USER");
        final String postgresPassword = System.getenv("POSTGRES_PASSWORD");
        final String postgresUrl = System.getenv("POSTGRES_URL");
        if (postgresUser == null || postgresPassword == null || postgresUrl == null) {
            logger.error("Missing environment variables: POSTGRES_USER and/or POSTGRES_PASSWORD and/or POSTGRES_URL");
            System.exit(1);
        }

        final String apiPortStr = System.getenv("API_PORT") != null ? System.getenv("API_PORT") : "8080";
        final int apiPort = Integer.parseInt(apiPortStr);
        final boolean debug = "true".equals(System.getenv("API_DEBUG"));

        final var config = new HikariConfig();
        config.setJdbcUrl(postgresUrl);
        config.setUsername(postgresUser);
        config.setPassword(postgresPassword);

        try (final var ds = new HikariDataSource(config)) {
            final var serverDBService = new PostgresServerDBService(ds);
            final var userDBService = new PostgresUserDBService(ds);
            final var appConfig = new AppConfig(apiPort, debug);

            final var webApi = new WebAPI(serverDBService, userDBService, appConfig);
            webApi.run();
        }
    }
}
